#ifndef __SIBASE_H__
#define __SIBASE_H__

#define SQUARED(X) ((X)*(X))

#define SCALE_YOTTA			(1.0E24)
#define SCALE_ZETTA			(1.0E21)
#define SCALE_EXA			(1.0E18)
#define SCALE_PETA			(1.0E15)
#define SCALE_TERA			(1.0E12)
#define SCALE_GIGA			(1.0E9)
#define SCALE_MEGA			(1.0E6)
#define SCALE_KILO			(1.0E3)
#define SCALE_HECTO			(1.0E2)
#define SCALE_DECA			(1.0E1)
#define	SCALE_BASE			(1.0E0)
#define SCALE_DECI			(1.0E-1)
#define SCALE_CENTI			(1.0E-2)
#define SCALE_MILLI			(1.0E-3)
#define SCALE_MICRO			(1.0E-6)
#define SCALE_NANO			(1.0E-9)
#define SCALE_PICO			(1.0E-12)
#define SCALE_FEMTO			(1.0E-15)
#define SCALE_ATTO			(1.0E-18)
#define SCALE_ZEPTO			(1.0E-21)
#define SCALE_YOCTO			(1.0E-24)

#define UNIT_BASE(TYPE, NAME)				\
	enum	{					\
		NAME ## _POSTOFFSET=0,			\
		NAME ## _PREOFFSET=0,			\
		NAME ## _SCALE=1,			\
		TYPE ## _ ## NAME ## _POSTOFFSET=0,	\
		TYPE ## _ ## NAME ## _PREOFFSET=0,	\
		TYPE ## _ ## NAME ## _SCALE=1	};

UNIT_BASE(FREQUENCY, HERTZ)
UNIT_BASE(FORCE, NEWTON)
UNIT_BASE(STRESS, PASCAL)
UNIT_BASE(ENERGY, JOULE)
UNIT_BASE(POWER, WATT)
UNIT_BASE(CHARGE, COULOMB)
UNIT_BASE(POTENTIAL, VOLT)
UNIT_BASE(CAPACITANCE, FARAD)
UNIT_BASE(RESISTANCE, OHM)
UNIT_BASE(RESISTANCE, SIEMENS)
UNIT_BASE(FLUX, WEBER)
UNIT_BASE(FIELD, TESLA)
UNIT_BASE(INDUCTANCE, HENRY)
UNIT_BASE(LFLUX, LUMEN)
UNIT_BASE(ILLUMINATION, LUX)
UNIT_BASE(RAD, BECQUEREL)
UNIT_BASE(ABSORBED_DOSE, GRAY)
UNIT_BASE(EQUIVALENT_DOSE, SIEVERT)
UNIT_BASE(CATALYTIC, KATAL)

#define MASS_GRAM_POSTOFFSET		0.00f
#define MASS_GRAM_PREOFFSET		0.00f
#define MASS_GRAM_SCALE			SCALE_MILLI

UNIT_BASE(LENGTH, METER)
UNIT_BASE(MASS, KILOGRAM)
UNIT_BASE(TIME, SECOND)
UNIT_BASE(CURRENT, AMPERE)
UNIT_BASE(TEMP, KELVIN)
UNIT_BASE(QUANTITY, MOLE)
UNIT_BASE(INTENSITY, CANDELA)
UNIT_BASE(ANGLE, RADIAN)

#endif/*__SIBASE_H__*/
