#include <stdio.h>

#include "sitypes.h"
#include "sitemp.h"
#include "sitime.h"
#include "silength.h"
#include "sivolume.h"
#include "sielect.h"
#include "silog.h"
#include "siarea.h"
#include "simass.h"

void test_volume(void);
void test_temperature(void);
void test_length(void);
void test_electrical(void);
void test_log(void);
void test_area(void);
void test_mass(void);
void test_constants(void);

int main(void)
{
  printf("Really Huge Number %f\n\n", 3.08567758E16);

  test_temperature();
  printf("\n");
  test_volume();
  printf("\n");
  test_length();
  printf("\n");
  test_electrical();
  printf("\n");
  test_log();
  printf("\n");
  test_area();
  printf("\n");
  test_mass();
  printf("\n");
  test_constants();
  printf("\n");

  return(0);
}

void test_constants(void)
{
//  printf("Earth's gravitational acceleration is %.2f m/s^2\n",
//    FROM_SIUNIT(EARTH_GRAVITY, VELOCITY_MPS));
}

void test_mass(void)
{
	double mass=SIBASE(3, KILO, MASS_GRAM);
	double id=SIUNIT(3, MASS_KILOGRAM);
	double small=SIBASE(3000, MILLI, MASS_GRAM);
	printf("Mass tests\n");

	printf("%.2f kg == %.2f kg\n",
		FROM_SIUNIT(mass, MASS_KILOGRAM),
		FROM_SIUNIT(id, MASS_KILOGRAM));

	printf("%.2f kg = %.2f g\n",
		FROM_SIUNIT(mass, MASS_KILOGRAM),
		FROM_SIUNIT(mass, MASS_GRAM));

	printf("%.2f mg = %.2f g = %.4f kg\n",
		FROM_SIBASE(small, MILLI, MASS_GRAM),
		FROM_SIUNIT(small, MASS_GRAM),
		FROM_SIBASE(small, KILO, MASS_GRAM));
}


void test_area(void)
{
	double area=SI_AREA(1, LENGTH_METER);

	printf("Area tests\n");

	printf("%.2f m^2 is %.2f cm^2\n",
		FROM_AREA(area, LENGTH_METER),
		FROM_AREABASE(area, CENTI, LENGTH_METER));

	printf("%.2f m^2 is %.2f foot^2\n",
		FROM_AREA(area, LENGTH_METER),
		FROM_AREA(area, LENGTH_FOOT));

	printf("%.2f m^2 is %.2f decifoot^2\n",
		FROM_AREA(area, LENGTH_METER),
		FROM_AREABASE(area, DECI, LENGTH_FOOT));

	printf("%.2f m^2 is %.2f inch^2\n",
		FROM_AREA(area, LENGTH_METER),
		FROM_AREA(area, LENGTH_INCH));
}

void test_log(void)
{
	double watts=SIUNIT(4, POWER_WATT);
	printf("Logarithmic tests\n");
	printf("%.2f watts is %.2f dbm\n", watts, LOGUNIT(watts, DBM));

	watts=SIBASE(200, MILLI, POWER_WATT);
	printf("%.2f mw is %.2f dbm\n",
		FROM_SIBASE(watts, MILLI, POWER_WATT),
		LOGUNIT(watts, DBM));

	watts=SIBASE(2, MICRO, POWER_WATT);
	printf("%.2f uw is %.2f dbm\n",
		FROM_SIBASE(watts, MICRO, POWER_WATT),
		LOGUNIT(watts, DBM));

	watts=SIUNIT(10, POWER_WATT);
	printf("%.2fW is %.2f dBW\n", watts, LOGUNIT(watts, DBW));
	watts=SIBASE(1, MEGA, POWER_WATT);
	printf("%.2fMW is %.2f dBW\n",
		FROM_SIBASE(watts, MEGA, POWER_WATT),
		LOGUNIT(watts, DBW));
}

void test_volume(void)
{
  double v=SIUNIT(1.0f, VOLUME_CUP);

  printf("Volume tests\n");
  printf("%0.2f cups is %.10f m^3\n", FROM_SIUNIT(v, VOLUME_CUP), v);
  printf("%0.2f cups is %0.2fl\n", FROM_SIUNIT(v, VOLUME_CUP),
	FROM_SIUNIT(v, VOLUME_LITER));
  printf("%0.2f cups is %0.2fml\n",
	FROM_SIUNIT(v, VOLUME_CUP),
	FROM_SIBASE(v, MILLI, VOLUME_LITER));
}

void test_temperature(void)
{
  double k=SIUNIT(68.0f, TEMP_FAHRENHEIT);

  printf("Temperature tests\n");
  printf("%0.2f Fahrenheit is %0.2f Kelvin\n",
	FROM_SIUNIT(k, TEMP_FAHRENHEIT), k);

  printf("%0.2f Fahrenheit is %0.2f Celsius\n",
	FROM_SIUNIT(k, TEMP_FAHRENHEIT),
	FROM_SIUNIT(k, TEMP_CELSIUS));
}

void test_length(void)
{
  double l=SIUNIT(60.0f, LENGTH_MILE);
  double t=SIUNIT(2.0f, TIME_HOUR);
  double lns=SIBASE(1, NANO, LENGTH_LIGHTSECOND);

  printf("Length tests\n");
  printf("%0.2f miles/%0.2f hours = %0.2f m/s\n",
	FROM_SIUNIT(l, LENGTH_MILE),
	FROM_SIUNIT(t, TIME_HOUR),
	l/t);
  printf("One light-nanosecond is %.2f cm\n",
	FROM_SIBASE(lns, CENTI, LENGTH_METER));
}

void test_electrical(void)
{
  double vsupply=SIUNIT(5.0f, POTENTIAL_VOLT);
  double vled=SIUNIT(3.5f, POTENTIAL_VOLT);
  double vres=vsupply-vled;
  double i=SIBASE(50, MILLI, CURRENT_AMPERE);

  printf("Electrical tests\n");

  printf("Resistor in series with a LED.\n"
	"\tVoltage supply is %0.2fV\n"
	"\tVoltage across LED (Vl) is %.2fV\n"
	"\tVoltage across resistor(Vres) is %.2fV\n",
		FROM_SIUNIT(vsupply, POTENTIAL_VOLT),
		FROM_SIUNIT(vled, POTENTIAL_VOLT),
		FROM_SIUNIT(vres, POTENTIAL_VOLT));

  printf("Vr = I*R, therefore %0.2fV = %0.2fmA * %0.2fohm\n",
	FROM_SIUNIT(vres, POTENTIAL_VOLT),
	FROM_SIBASE(i, MILLI, CURRENT_AMPERE),
	FROM_SIUNIT(vres/i, RESISTANCE_OHM));

  printf("Vl = I*Rled, therefore %0.2fV = %0.2fmA * %0.2fohm\n",
	FROM_SIUNIT(vled, POTENTIAL_VOLT),
	FROM_SIBASE(i, MILLI, CURRENT_AMPERE),
	FROM_SIUNIT(vled/i, RESISTANCE_OHM));
}
