/**
 *	Simplifies physical formulae by converting everything to 
 *	standard SI units -- meters, kilograms, seconds, amperes, kelvin.
 *	This should help keep everything in the correct scale even when 
 *	using mixed units -- NASA, are you listening?  For example, 
 *      dividing 50 miles by 7 minutes would give you a correct answer
 *	in the SI measure of meters per second:
 *
 *		SIUNIT(50, LENGTH_MILES) / SIUNIT(7, TIME_MINUTES)
 *
 *	If you need a particular kind of unit back from it you can: 
 *
 *		FROM_SIUNIT(238.0f, TEMP_FAHRENHEIT)
 *
 *	Even when working with plain meters and seconds it plainly 
 *	labels exactly what numbers are what units.
 */
#ifndef __SITYPES_H__
#define __SITYPES_H__

#include "sibase.h"

//#define SIUNIT(VALUE, UNIT)		\
//	(((VALUE + UNIT ## _PREOFFSET) * UNIT ## _SCALE) + UNIT ## _POSTOFFSET)

#define SIBASE(VALUE, PREFIX, UNIT)					\
	((( (VALUE * (SCALE_ ## PREFIX)) + UNIT ## _PREOFFSET) *	\
		UNIT ## _SCALE) + UNIT ## _POSTOFFSET)

#define SIUNIT(VALUE, UNIT) SIBASE(VALUE, BASE, UNIT)


//#define FROM_SIUNIT(VALUE, UNIT)	\
//	(((VALUE - UNIT ## _POSTOFFSET)/UNIT ## _SCALE)-UNIT ## _PREOFFSET)

#define FROM_SIBASE(VALUE, PREFIX, UNIT)			\
	((((VALUE - UNIT ## _POSTOFFSET)/UNIT ## _SCALE)-	\
		UNIT ## _PREOFFSET) / SCALE_ ## PREFIX)

#define FROM_SIUNIT(VALUE, UNIT) FROM_SIBASE(VALUE, BASE, UNIT)

#endif/*__SITYPES_H__*/
